# Permacomputing Principles Zine

# This script writes a html file scraping the information from the wiki page https://permacomputing.net/Principles/
# It includes an image, a title, an introduction and a colophon.
# it uses urllib for scrapting, BeautifulSoup for parsing and paged js for printing layout production. 

import urllib
from bs4 import BeautifulSoup

# here the link of the section to print
url = "https://permacomputing.net/Principles/"

response = urllib.request.urlopen(url)
html = response.read()
soup = BeautifulSoup(html, 'html.parser')

# let's take just the body section of the wiki page
body = soup.find_all('body')

# Zine title header
title = f'''<header>permacomputing/Principles</header>'''

# Permacomputing image tag 
image = f'''<img id="image" src="permacomputing.png"></img>'''

colophon = f'''<div id="colophon"><h2>Colophon:</h2>
        <p>This fanzine was made scraping the Permacomputing principles wiki page: https://permacomputing.net/Principles/</p>
        <p>Its distribution is free. You are invited to read, copy and share it with others.</p>
        <p>Typefaces: Monospace and Basteleur-moon.</p>
        <p>ZineCamp * 2022</p></div>'''

# Manually copy pasted introduction from https://permacomputing.net/
intro= f'''<p class="intro">Permacomputing is a more sustainable approach to computer and network technology inspired by permaculture. <br>
In a time where computing epitomizes industrial waste, permacomputing encourages a more sustainable approach, maximizing hardware lifespans, minimizing energy use and focussing on the use of already available computational resources. Permacomputing asks the question whether it is possible to rethink computing in the same way as permaculture rethinks agriculture. Permaculture is the science and practice of creating semi-permanent ecosystems of nature. The resilience of any such ecosystem is equal to its diversity and interconnectedness. Permaculture design is a system of assembling conceptual, material and strategic components in a pattern which functions to benefit life in all its forms. It seeks to provide a sustainable and secure place for living things on this earth. <br>
At first it may seems paradoxical to connect permaculture and computation. Indeed, an extractive technology that depends on a wasteful use of finite resources can hardly be permanent. Therefore, by making this connection, what we are truly asking is whether or not there can be a place for computer and network technology in a world where humans contribute to the well-being of the biosphere rather than destroy it? And if yes, how? <br>
Permacomputing wants to imagine such a place and take steps towards it. It is therefore both utopian and practical. We want to find out how we can practice good relations with the Earth by learning from ecological systems to leverage and re-center existing technologies and practices. A radical reduction of wastefulness is a fundamental aspect of it: maximize the hardware lifespans, minimize the energy use. And this is not just about a set of technical problems to be fixed­—the attitudes also need a radical turn. Understandability is aesthetics, virtual does not mean immaterial and doing things with less is not a return to the past. We want to investigate what a permacomputing way of life could be, and what sort of transformative computational culture and aesthetics it could bring forward.</p>'''

content = f'''<!DOCTYPE html>
<html>
 <head>
      <meta content="text/html; charset=utf-8" http-equiv="Content-Type"/>
  <title>
   Permacomputing Principles
  </title>
  <meta content="width=device-width, initial-scale=1" name="viewport"/>
      <link href="style.css" rel="stylesheet" type="text/css"/>
      <!--     Local css from the permaculture wiki -->
      <link href="local.css" rel="stylesheet" type="text/css"/>
      <!--     Print css details -->
      <link href="style-print.css" rel="stylesheet" type="text/css" media="print">
      <!--      paged-js interface and script -->
      <link href="paged-js/interface.css" rel="stylesheet">
      <script src="paged-js/polyfill.js"></script>
 </head>
    {title}
    {intro}
    {image}
    {body[0]} 
    {colophon}
</html>'''

website = open('index.html','w')

website.write(content)
website.close()